pub enum ClassHashError {
Match(String),
RegexError,
}Expand description
Errors that can occur when validating or creating class hashes.
Each error variant provides detailed information about what went wrong and includes actionable suggestions for fixing the issue.
Variants
Implementations
Sourceimpl ClassHashError
impl ClassHashError
pub const fn error_code(&self) -> &'static str