Struct ApiClient

pub struct ApiClient { /* private fields */ }

Implementations

Source

impl ApiClient

Currently only GetJobStatus and VerifyClass are public available apis. In the future, the get class api should be moved to using public apis too. TODO: Change get class api to use public apis.

pub fn new(base: Url) -> Result<Self, ApiClientError>

Errors

Fails if provided Url cannot be a base. We rely on that invariant in other methods.

pub fn get_class_url( &self, class_hash: &ClassHash, ) -> Result<Url, ApiClientError>

Errors

Will return Err if the URL cannot be a base.

pub fn get_class(&self, class_hash: &ClassHash) -> Result<bool, ApiClientError>

Errors

Returns Err if the required class_hash is not found or on network failure.

pub fn verify_class_url( &self, class_hash: &ClassHash, ) -> Result<Url, ApiClientError>

Errors

Will return Err if the URL cannot be a base.

pub fn verify_class( &self, class_hash: &ClassHash, license: Option<String>, name: &str, project_metadata: ProjectMetadataInfo, files: &[FileInfo], ) -> Result<String, ApiClientError>

Errors

Will return Err on network request failure or if can’t gather file contents for submission.

pub fn get_job_status_url( &self, job_id: impl AsRef<str>, ) -> Result<Url, ApiClientError>

Errors

Will return Err if the URL cannot be a base.

pub fn get_job_status( &self, job_id: impl Into<String> + Clone, ) -> Result<Option<VerificationJob>, ApiClientError>

Errors

Will return Err on network error or if the verification has failed.